#include <config.h>

#include <sys/stat.h>

#include <stdlib.h>
#include <unistd.h>
#include <errno.h>

#include "sudo.h"

#ifdef HAVE_SELINUX
bool
sudo_check_temp_file(int tfd, const char *tfile, uid_t uid, struct stat *sb)
{
    struct stat sbuf;
    debug_decl(sudo_check_temp_file, SUDO_DEBUG_UTIL);

    if (sb == NULL)
       sb = &sbuf;

    if (fstat(tfd, sb) == -1) {
       sudo_warn(U_("unable to stat %s"), tfile);
       debug_return_bool(false);
    }
    if (!S_ISREG(sb->st_mode)) {
       sudo_warnx(U_("%s: not a regular file"), tfile);
       debug_return_bool(false);
    }
    if ((sb->st_mode & ALLPERMS) != (S_IRUSR|S_IWUSR)) {
       sudo_warnx(U_("%s: bad file mode: 0%o"), tfile, sb->st_mode & ALLPERMS);
       debug_return_bool(false);
    }
    if (sb->st_uid != uid) {
       sudo_warnx(U_("%s is owned by uid %u, should be %u"),
           tfile, (unsigned int)sb->st_uid, (unsigned int)uid);
       debug_return_bool(false);
    }
    debug_return_bool(true);
}
#endif /* SELINUX */
